// Persistence Of Vision raytracer sample file.
// File: phot_met_glass.pov
// Desc: metal, glass and photons sample
// Date: August 2001
// Auth: Christoph Hormann

// -w320 -h160
// -w512 -h256 +a0.3

// Updated: 07Aug2008 (jh) for v3.7 distribution

#if (version < 3.7)
  #version 3.5;
#end

#include "colors.inc"
#include "glass.inc"

global_settings {
  // conditionally comply with gamma correction handling
  #if (version < 3.7)
    assumed_gamma 1.0
  #end
  max_trace_level 25
  photons {
    spacing 0.003
    autostop 0
    jitter 0
  }
}

camera {
location < 4, -0, 0.5 >  //bak test
  right       (4/3)*x
  look_at     <0,-1.0,0> //bak test 
  angle       29
}

light_source {
  <-3, 10, 18>
  color rgb <1.3, 1.2, 1.1>

  photons {
    reflection on
    refraction on
  }

  media_interaction on
}

plane {
  y, -1.45
  texture {
    pigment {
      color rgb 1.0
    }
  }
}


#declare densFileName = "Tracer-1.64.df3"
#declare fileName = "waterMesh-1.64.pov"

//#declare fileName = concat("waterMesh-", str(clock, 1, 2), ".pov")
//#declare densFileName = concat("Tracer-", str(clock, 1, 2), ".df3");

//#declare SmokeColor=rgb <1,.5,0>; // orangish smoke
mesh2{

#include fileName

hollow    
    material {
        texture {
        pigment { color Col_Glass_Clear }
        finish { F_Glass6 }
        pigment{ color rgbt<1,1,1,1> }
      }
      interior {
        I_Glass_Exp(2)
        fade_color Col_Red_03
//            media { absorption 0  emission SmokeColor 
            media {
                absorption 20*<1., 1., 0.>
                intervals 1
                samples 5

                 method 3

                                                                
           scattering{ 1, // Type 1 = isotropic scattering, 2 = Mie haze, 3 = Mie murky 
                          // Type 4 = Rayleigh scattering,  5 = Henyey-Greenstein scattering 
                       <0.2,0,1>*30.00        // color of scattering haze  
                       extinction  0.2   // 0 ~ 1 extinction 
                       // how fast the scattering media absorbs light 
                       // useful i.e. when the media absorbs too much light
                      // eccentricity i.e. -0.6 ~ +0.6 (if type>1 )
           } // end scattering   


             emission 12*<0.1, 0., 1.>
                density{  density_file df3 densFileName
                              interpolate 2
                              scale <1,2,1>
                              translate <-0.5, -1.5, -0.5>
 //                             density_map { [0 rgb 0][.8 rgb 1] }
                    color_map {

                    [0.00 rgb 0] // density at the border of the media
                    [0.05 rgb 0.1]
                    [0.20 rgb 0.4]
                    [0.30 rgb 0.6]
                    [0.40 rgb 0.8]
                    [0.60 rgb 1.0]
                    [1.00 rgb 1.0] // densitiy at the center of the media*/
                               }

                             }
                   }

      }
    }

  photons {
    target
    reflection on
    refraction on
    collect off
  }
  }




